//**************************************************
//
// drawarea.cpp - Defines a generic class for wrapping
//	          drawing type events (mouse, repaint, etc.)
//		  into a single signal to emit to a parent.
//
// Written by: H. Welch August 2000
//	       Based loosely on preliminary code by Benjamin Stocks
//
// Modified by: E. Durant 26 September 2003
//		qualified string with std:: for portability
//**************************************************

#include <drawarea.h>
 
// Qt library headers to support the class widgets
#include <qwidget.h>


//*******************************************************
//
// DrawArea::DrawArea - Initializes the basic widget
//			
//
// Written by: H. Welch August 2000
//
// Paramenters: parent - The widget to draw the shell in 
//                       Default NULL for top level widget
//              name - Name for the widget
//
// Returns: NOTHING
//
// Calls:
//	  Qt Library
//
// Globals: NONE
//
//********************************************************

DrawArea::DrawArea (QWidget* parent, const std::string& name) :
		QWidget(parent, name.c_str())
{
	// Do nothing
}

//*******************************************************
//
// DrawArea::~DrawArea - Drawing Area destructor
//
// Written by: H. Welch August 2000
//
// Paramenters: NONE
//
// Returns: NOTHING
//
// Calls: NONE
//
// Globals: NONE
//
//********************************************************	
		
DrawArea::~DrawArea()
{
	// Do nothing
}

//*******************************************************
//
// DrawArea::mousePressEvent - virtual method of QWidget
//			       that is invoked for every
//                             mouse press inside this widget
//
// Written by: H. Welch August 2000
//
// Paramenters: mouseEvent - Event data
//
// Returns: NOTHING
//
// Calls: emits signal to parent for processing
//
// Globals: NONE
//
//********************************************************	

void DrawArea::mousePressEvent(QMouseEvent* mouseEvent)
{
	// Emit signal to parent
	// Make the event data generic
	emit drawAreaEvent((QEvent*) mouseEvent);
}


//*******************************************************
//
// DrawArea::mouseMoveEvent - virtual method of QWidget
//			      that is invoked for mouse
//			      movement while a button is 
//                            pressed inside this widget
//
// Written by: H. Welch August 2000
//
// Paramenters: mouseEvent - Event data
//
// Returns: NOTHING
//
// Calls: emits signal to parent for processing
//
// Globals: NONE
//
//********************************************************	

void DrawArea::mouseMoveEvent(QMouseEvent* mouseEvent)
{
	// Emit signal to parent
	// Make the event data generic
	emit drawAreaEvent((QEvent*) mouseEvent);
}

//*******************************************************
//
// DrawArea::mouseReleaseEvent - virtual method of QWidget
//			         that is invoked for every
//                               mouse button release inside this widget
//
// Written by: H. Welch August 2000
//
// Paramenters: mouseEvent - Event data
//
// Returns: NOTHING
//
// Calls: emits signal to parent for processing
//
// Globals: NONE
//
//********************************************************	

void DrawArea::mouseReleaseEvent(QMouseEvent* mouseEvent)
{
	// Emit signal to parent
	// Make the event data generic
	emit drawAreaEvent((QEvent*) mouseEvent);
}

//*******************************************************
//
// DrawArea::paintEvent - virtual method of QWidget
//			  that is invoked whenever the
//			  widget data must be redrawn
//
// Written by: H. Welch August 2000
//
// Paramenters: mouseEvent - Event data
//
// Returns: NOTHING
//
// Calls: emits signal to parent for processing
//
// Globals: NONE
//
//********************************************************	

void DrawArea::paintEvent(QPaintEvent* paintEvent)
{
	// Emit signal to parent
	// Make the event data generic
	emit drawAreaEvent((QEvent*) paintEvent);
}

